Toronto_SSIM: Toronto neighbourhood deprivation indices and commuting...

Toronto_SSIMR Documentation

Toronto neighbourhood deprivation indices and commuting pattern (2016)

Description

An sf polygon object for the Toronto Census Subdivision, Ontario, Canada. Each polygon corresponds to a Census Tract (CT) and includes two neighbourhood-level deprivation indices and one census variable, which can be used as inputs to ssim_polygon and ssim_bandwidth.

Usage

Toronto_SSIM

Format

An sf data frame with one row per Census Tract and the following key columns:

CIMD

Canadian Index of Multiple Deprivation (situational dimension), 2016. Higher values indicate greater deprivation.

PP

Pampalon deprivation index (social dimension), 2016.

Commute

Percentage of households commuting within the Census Subdivision of residence, 2016.

geometry

sfc polygon geometry column.

Statistics Canada, 2016 Census of Population.

Examples

data("Toronto_SSIM")
plot(Toronto_SSIM["CIMD"], border = NA)

SSIMmap documentation built on May 8, 2026, 1:07 a.m.