| fwi_0818_bc | R Documentation |
Daily Canadian Fire Weather Index (FWI) for the province of British
Columbia, Canada, on 18 August 2023, at a 2 km spatial resolution. This
date also represents conditions during the peak summer fire season and is
typically expected to show high spatial similarity to
fwi_0816_bc.
fwi_0818_bc
A packed terra raster object with one numeric layer
(FWI values).
The object is stored as a packed terra raster (created with
terra::wrap()). Use terra::unwrap() to convert it back to a
regular terra raster before use.
Canadian Forest Fire Weather Index System.
data("fwi_0818_bc")
fwi_0818_bc <- terra::unwrap(fwi_0818_bc)
terra::plot(fwi_0818_bc, main = "FWI - 18 August 2023")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.