| Toronto_SSIM | R Documentation |
An sf polygon object for the Toronto Census Subdivision, Ontario,
Canada. Each polygon corresponds to a Census Tract (CT) and includes two
neighbourhood-level deprivation indices and one census variable, which can
be used as inputs to ssim_polygon and
ssim_bandwidth.
Toronto_SSIM
An sf data frame with one row per Census Tract and the
following key columns:
Canadian Index of Multiple Deprivation (situational dimension), 2016. Higher values indicate greater deprivation.
Pampalon deprivation index (social dimension), 2016.
Percentage of households commuting within the Census Subdivision of residence, 2016.
sfc polygon geometry column.
Statistics Canada, 2016 Census of Population.
data("Toronto_SSIM")
plot(Toronto_SSIM["CIMD"], border = NA)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.